@@ -11,8 +11,10 @@ const char* ffDetectBootmgr(FFBootmgrResult* result)
     if (ffReadFileData(FF_EFIVARS_PATH_PREFIX "BootCurrent-" FF_EFI_GLOBAL_GUID, sizeof(buffer), buffer) != 6)
         return "Failed to read efivar: BootCurrent";
 
-    uint16_t value = *(uint16_t *)&buffer[4];
-    snprintf((char*) buffer, sizeof(buffer), FF_EFIVARS_PATH_PREFIX "Boot%04X-" FF_EFI_GLOBAL_GUID, value);
+
+    result->order = *(uint16_t *)&buffer[4];
+
+    snprintf((char*) buffer, sizeof(buffer), FF_EFIVARS_PATH_PREFIX "Boot%04X-" FF_EFI_GLOBAL_GUID, result->order);
 
     ssize_t size = ffReadFileData((const char*) buffer, sizeof(buffer), buffer);
     if (size < 5 + (int) sizeof(FFEfiLoadOption) || size == (ssize_t) sizeof(buffer))
