@@ -1,6 +1,20 @@
 #pragma once
 
 #include "fastfetch.h"
+#include "modules/localip/option.h"
+
+#ifndef IN6_IS_ADDR_GLOBAL
+#define IN6_IS_ADDR_GLOBAL(a) \
+        ((((const uint32_t *) (a))[0] & htonl(0x70000000)) == htonl(0x20000000))
+#endif
+#ifndef IN6_IS_ADDR_UNIQUE_LOCAL
+#define IN6_IS_ADDR_UNIQUE_LOCAL(a) \
+        ((((const uint32_t *) (a))[0] & htonl(0xfe000000)) == htonl(0xfc000000))
+#endif
+#ifndef IN6_IS_ADDR_LINKLOCAL
+#define IN6_IS_ADDR_LINKLOCAL(a) \
+        ((((const uint32_t *) (a))[0] & htonl(0xffc00000)) == htonl(0xfe800000))
+#endif
 
 typedef struct FFLocalIpResult
 {
@@ -11,7 +25,7 @@ typedef struct FFLocalIpResult
     FFstrbuf flags;
     int32_t mtu;
     int32_t speed; // in Mbps
-    bool defaultRoute;
+    FFLocalIpType defaultRoute;
 } FFLocalIpResult;
 
 typedef struct FFLocalIpNIFlag
@@ -20,7 +34,7 @@ typedef struct FFLocalIpNIFlag
     const char *name;
 } FFLocalIpNIFlag;
 
-static inline void ffLocalIpFillNIFlags(FFstrbuf *buf, uint32_t flag, const FFLocalIpNIFlag names[])
+static inline void ffLocalIpFillNIFlags(FFstrbuf *buf, uint64_t flag, const FFLocalIpNIFlag names[])
 {
     for (const FFLocalIpNIFlag *nf = names; flag && nf->name; ++nf)
     {
