@@ -72,7 +72,7 @@ static void printBattery(FFBatteryOptions* options, FFBatteryResult* result, uin
                 ffStrbufAppend(&str, &result->status);
         }
 
-        if(result->temperature == result->temperature) //FF_BATTERY_TEMP_UNSET
+        if(result->temperature != FF_BATTERY_TEMP_UNSET)
         {
             if(str.length > 0)
                 ffStrbufAppendS(&str, " - ");
@@ -125,7 +125,7 @@ static void printBattery(FFBatteryOptions* options, FFBatteryResult* result, uin
     }
 }
 
-void ffPrintBattery(FFBatteryOptions* options)
+bool ffPrintBattery(FFBatteryOptions* options)
 {
     FF_LIST_AUTO_DESTROY results = ffListCreate(sizeof(FFBatteryResult));
 
@@ -134,12 +134,12 @@ void ffPrintBattery(FFBatteryOptions* options)
     if (error)
     {
         ffPrintError(FF_BATTERY_MODULE_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, "%s", error);
-        return;
+        return false;
     }
     if(results.length == 0)
     {
         ffPrintError(FF_BATTERY_MODULE_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, "%s", "No batteries found");
-        return;
+        return false;
     }
 
     for(uint32_t i = 0; i < results.length; i++)
@@ -157,47 +157,20 @@ void ffPrintBattery(FFBatteryOptions* options)
         ffStrbufDestroy(&result->serial);
         ffStrbufDestroy(&result->manufactureDate);
     }
-}
-
-bool ffParseBatteryCommandOptions(FFBatteryOptions* options, const char* key, const char* value)
-{
-    const char* subKey = ffOptionTestPrefix(key, FF_BATTERY_MODULE_NAME);
-    if (!subKey) return false;
-    if (ffOptionParseModuleArgs(key, subKey, value, &options->moduleArgs))
-        return true;
-
-    if (ffTempsParseCommandOptions(key, subKey, value, &options->temp, &options->tempConfig))
-        return true;
-
-    #ifdef _WIN32
-        if (ffStrEqualsIgnCase(subKey, "use-setup-api"))
-        {
-            options->useSetupApi = ffOptionParseBoolean(value);
-            return true;
-        }
-    #endif
-
-    if (ffPercentParseCommandOptions(key, subKey, value, &options->percent))
-        return true;
-
-    return false;
+    return true;
 }
 
 void ffParseBatteryJsonObject(FFBatteryOptions* options, yyjson_val* module)
 {
-    yyjson_val *key_, *val;
+    yyjson_val *key, *val;
     size_t idx, max;
-    yyjson_obj_foreach(module, idx, max, key_, val)
+    yyjson_obj_foreach(module, idx, max, key, val)
     {
-        const char* key = yyjson_get_str(key_);
-        if(ffStrEqualsIgnCase(key, "type") || ffStrEqualsIgnCase(key, "condition"))
-            continue;
-
         if (ffJsonConfigParseModuleArgs(key, val, &options->moduleArgs))
             continue;
 
         #ifdef _WIN32
-        if (ffStrEqualsIgnCase(key, "useSetupApi"))
+        if (unsafe_yyjson_equals_str(key, "useSetupApi"))
         {
             options->useSetupApi = yyjson_get_bool(val);
             continue;
@@ -210,28 +183,23 @@ void ffParseBatteryJsonObject(FFBatteryOptions* options, yyjson_val* module)
         if (ffPercentParseJsonObject(key, val, &options->percent))
             continue;
 
-        ffPrintError(FF_BATTERY_MODULE_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, "Unknown JSON key %s", key);
+        ffPrintError(FF_BATTERY_MODULE_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, "Unknown JSON key %s", unsafe_yyjson_get_str(key));
     }
 }
 
 void ffGenerateBatteryJsonConfig(FFBatteryOptions* options, yyjson_mut_doc* doc, yyjson_mut_val* module)
 {
-    __attribute__((__cleanup__(ffDestroyBatteryOptions))) FFBatteryOptions defaultOptions;
-    ffInitBatteryOptions(&defaultOptions);
-
-    ffJsonConfigGenerateModuleArgsConfig(doc, module, &defaultOptions.moduleArgs, &options->moduleArgs);
+    ffJsonConfigGenerateModuleArgsConfig(doc, module, &options->moduleArgs);
 
     #ifdef _WIN32
-    if (defaultOptions.useSetupApi != options->useSetupApi)
         yyjson_mut_obj_add_bool(doc, module, "useSetupApi", options->useSetupApi);
     #endif
 
-    ffTempsGenerateJsonConfig(doc, module, defaultOptions.temp, defaultOptions.tempConfig, options->temp, options->tempConfig);
-
-    ffPercentGenerateJsonConfig(doc, module, defaultOptions.percent, options->percent);
+    ffTempsGenerateJsonConfig(doc, module, options->temp, options->tempConfig);
+    ffPercentGenerateJsonConfig(doc, module, options->percent);
 }
 
-void ffGenerateBatteryJsonResult(FFBatteryOptions* options, yyjson_mut_doc* doc, yyjson_mut_val* module)
+bool ffGenerateBatteryJsonResult(FFBatteryOptions* options, yyjson_mut_doc* doc, yyjson_mut_val* module)
 {
     FF_LIST_AUTO_DESTROY results = ffListCreate(sizeof(FFBatteryResult));
 
@@ -239,7 +207,7 @@ void ffGenerateBatteryJsonResult(FFBatteryOptions* options, yyjson_mut_doc* doc,
     if (error)
     {
         yyjson_mut_obj_add_str(doc, module, "error", error);
-        return;
+        return false;
     }
 
     yyjson_mut_val* arr = yyjson_mut_obj_add_arr(doc, module, "result");
@@ -254,7 +222,10 @@ void ffGenerateBatteryJsonResult(FFBatteryOptions* options, yyjson_mut_doc* doc,
         yyjson_mut_obj_add_strbuf(doc, obj, "status", &battery->status);
         yyjson_mut_obj_add_strbuf(doc, obj, "technology", &battery->technology);
         yyjson_mut_obj_add_strbuf(doc, obj, "serial", &battery->serial);
-        yyjson_mut_obj_add_real(doc, obj, "temperature", battery->temperature);
+        if (battery->temperature != FF_BATTERY_TEMP_UNSET)
+            yyjson_mut_obj_add_real(doc, obj, "temperature", battery->temperature);
+        else
+            yyjson_mut_obj_add_null(doc, obj, "temperature");
         yyjson_mut_obj_add_uint(doc, obj, "cycleCount", battery->cycleCount);
         if (battery->timeRemaining > 0)
             yyjson_mut_obj_add_int(doc, obj, "timeRemaining", battery->timeRemaining);
@@ -271,12 +242,32 @@ void ffGenerateBatteryJsonResult(FFBatteryOptions* options, yyjson_mut_doc* doc,
         ffStrbufDestroy(&battery->status);
         ffStrbufDestroy(&battery->serial);
     }
+
+    return true;
 }
 
-static FFModuleBaseInfo ffModuleInfo = {
+void ffInitBatteryOptions(FFBatteryOptions* options)
+{
+    ffOptionInitModuleArg(&options->moduleArgs, "");
+    options->temp = false;
+    options->tempConfig = (FFColorRangeConfig) { 60, 80 };
+    options->percent = (FFPercentageModuleConfig) { 50, 20, 0 };
+
+    #ifdef _WIN32
+        options->useSetupApi = false;
+    #endif
+}
+
+void ffDestroyBatteryOptions(FFBatteryOptions* options)
+{
+    ffOptionDestroyModuleArg(&options->moduleArgs);
+}
+
+FFModuleBaseInfo ffBatteryModuleInfo = {
     .name = FF_BATTERY_MODULE_NAME,
     .description = "Print battery capacity, status, etc",
-    .parseCommandOptions = (void*) ffParseBatteryCommandOptions,
+    .initOptions = (void*) ffInitBatteryOptions,
+    .destroyOptions = (void*) ffDestroyBatteryOptions,
     .parseJsonObject = (void*) ffParseBatteryJsonObject,
     .printModule = (void*) ffPrintBattery,
     .generateJsonResult = (void*) ffGenerateBatteryJsonResult,
@@ -299,21 +290,3 @@ static FFModuleBaseInfo ffModuleInfo = {
         {"Battery time remaining (formatted)", "time-formatted"},
     }))
 };
-
-void ffInitBatteryOptions(FFBatteryOptions* options)
-{
-    options->moduleInfo = ffModuleInfo;
-    ffOptionInitModuleArg(&options->moduleArgs, "");
-    options->temp = false;
-    options->tempConfig = (FFColorRangeConfig) { 60, 80 };
-    options->percent = (FFPercentageModuleConfig) { 50, 20, 0 };
-
-    #ifdef _WIN32
-        options->useSetupApi = false;
-    #endif
-}
-
-void ffDestroyBatteryOptions(FFBatteryOptions* options)
-{
-    ffOptionDestroyModuleArg(&options->moduleArgs);
-}
