@@ -4,7 +4,7 @@
 
 #define FF_PHYSICALDISK_MODULE_NAME "PhysicalDisk"
 
-void ffPrintPhysicalDisk(FFPhysicalDiskOptions* options);
+bool ffPrintPhysicalDisk(FFPhysicalDiskOptions* options);
 void ffInitPhysicalDiskOptions(FFPhysicalDiskOptions* options);
 void ffDestroyPhysicalDiskOptions(FFPhysicalDiskOptions* options);
 
